emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[nongnu] elpa/parseedn 3e0b5d729e 09/32: Fix references in tests: s/pars


From: ELPA Syncer
Subject: [nongnu] elpa/parseedn 3e0b5d729e 09/32: Fix references in tests: s/parseclj/parseedn
Date: Tue, 28 Dec 2021 14:04:41 -0500 (EST)

branch: elpa/parseedn
commit 3e0b5d729eb2ec1d2278451d065bdd7ab0b7d71e
Author: Arne Brasseur <arne@arnebrasseur.net>
Commit: Arne Brasseur <arne@arnebrasseur.net>

    Fix references in tests: s/parseclj/parseedn
---
 test/parseedn-el-parity-test.el                       | 2 +-
 test/{parseclj-test-data.el => parseedn-test-data.el} | 6 +++---
 test/parseedn-test.el                                 | 8 ++++----
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/test/parseedn-el-parity-test.el b/test/parseedn-el-parity-test.el
index c58641a4f3..330669af8f 100644
--- a/test/parseedn-el-parity-test.el
+++ b/test/parseedn-el-parity-test.el
@@ -30,7 +30,7 @@
 ;;; Code:
 
 (require 'ert)
-(require 'parseclj)
+(require 'parseedn)
 (eval-when-compile (require 'subr-x)) ;; for things like hash-table-keys
 
 (ert-deftest whitespace ()
diff --git a/test/parseedn-test.el b/test/parseedn-test.el
index eb4cfb41fa..d9c3ce79d3 100644
--- a/test/parseedn-test.el
+++ b/test/parseedn-test.el
@@ -28,9 +28,9 @@
 ;;; Code
 
 (require 'ert)
-(require 'parseclj)
+(require 'parseedn)
 
-(load "test/parseclj-test-data.el")
+(load "test/parseedn-test-data.el")
 
 (ert-deftest parseedn-print-test ()
   (should (equal (parseedn-print-str nil) "nil"))
@@ -56,7 +56,7 @@
                        (insert ,(a-get data :source))
                        (goto-char 1)
                        (should (a-equal (parseedn-read) ',(a-get data 
:edn)))))))))
-        parseclj-test-data)))
+        parseedn-test-data)))
 
 (defmacro define-parseedn-roundtrip-tests ()
   `(progn
@@ -69,7 +69,7 @@
                   `(ert-deftest ,test-name ()
                      :tags '(parseedn-rountrip)
                      (should (equal (parseedn-print-str (car ',(a-get data 
:edn))) ,(a-get data :source))))))))
-        parseclj-test-data)))
+        parseedn-test-data)))
 
 (define-parseedn-read-tests)
 (define-parseedn-roundtrip-tests)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/test/parseclj-test-data.el b/test/parseedn-test-data.el
similarity index 99%
rename from test/parseclj-test-data.el
rename to test/parseedn-test-data.el
index 1b739de399..a862403030 100644
--- a/test/parseclj-test-data.el
+++ b/test/parseedn-test-data.el
@@ -1,4 +1,4 @@
 ;;; parseclj-test-data.el --- Clojure/EDN parser - test data
 
 ;; Copyright (C) 2017-2018  Arne Brasseur
 
@@ -27,7 +27,7 @@
 
 ;;; Code:
 
-(setq parseclj-test-data
+(setq parseedn-test-data
       (a-list
 
        "simple-list"
@@ -342,4 +342,4 @@
         :source "[nil true false]"
         :edn '([nil t nil]))))
 
-;;; parseclj-test-data.el ends here
+;;; parseedn-test-data.el ends here
@@ -1,4 +1,4 @@
-;;; parseclj-test-data.el --- Clojure/EDN parser - test data
+;;; parseedn-test-data.el --- Clojure/EDN parser - test data
 
 ;; Copyright (C) 2017-2018  Arne Brasseur